@@ -37,7 +37,7 @@ class BasePublisher(object):
         '''
         @ensure_csrf_cookie
         def view(request, *args, **kwargs):
-            '''A wrapper view to instanciate and dispatch'''
+            '''A wrapper view to instantiate and dispatch'''
             self = cls(request, *args, **kwargs)
             return self.dispatch(request, **kwargs)
 
@@ -195,12 +195,12 @@ class Publisher(engine.JsonEngine, BasePublisher):
             'objects': page.object_list,
         }
 
-    def get_request_data(self):
+    def get_request_data(self, default=None):
         '''Retrieve data from request'''
         ctype = self.request.META.get('CONTENT_TYPE', '').split(';')[0].strip()
         if ctype in self.CONTENT_TYPES:
             if not self.request.body:
-                return None
+                return default
             return self.loads(self.request.body)
         if self.request.method == 'GET':
             return self.request.GET
